@@ -33,9 +33,7 @@ plot.see_bayesfactor_parameters <- function(x,
 
   # if we have intercept-only models, keep at least the intercept
   intercepts_points <- which(.in_intercepts(d_points$ind))
-  if (length(intercepts_points) &&
-    nrow(d_points) > length(intercepts_points) &&
-    !show_intercept) {
+  if (length(intercepts_points) && (nrow(d_points) > length(intercepts_points)) && !show_intercept) {
     intercepts_data <- which(.in_intercepts(plot_data$ind))
     plot_data <- plot_data[-intercepts_data, ]
     d_points <- d_points[-intercepts_points, ]
@@ -69,11 +67,11 @@ plot.see_bayesfactor_parameters <- function(x,
     ) +
     theme(legend.position = "bottom")
 
-  if (length(unique(plot_data$ind)) > 1) {
+  if (length(unique(plot_data$ind)) > 1L) {
     p <- p + facet_wrap(~ind, scales = "free")
   }
 
-  if (length(hypothesis) > 1) {
+  if (length(hypothesis) > 1L) {
     rope <- range(hypothesis)
     p <-
       p + annotate(
