@@ -189,9 +189,9 @@ plot.see_compare_parameters <- function(x,
 #' @export
 data_plot.see_compare_parameters <- function(x, ...) {
   col_coefficient <- which(grepl("^(Coefficient|Log-Odds|Log-Mean|Odds Ratio|Risk Ratio|IRR)\\.", colnames(x)))
-  col_ci_low <- which(grepl("^CI_low\\.", colnames(x)))
-  col_ci_high <- which(grepl("^CI_high\\.", colnames(x)))
-  col_p <- which(grepl("^p\\.", colnames(x)))
+  col_ci_low <- which(startsWith(colnames(x), "CI_low."))
+  col_ci_high <- which(startsWith(colnames(x), "CI_high."))
+  col_p <- which(startsWith(colnames(x), "p."))
 
   out1 <- .reshape_to_long(
     x,
