@@ -142,7 +142,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 
   out$HDI_low <- sapply(out$x, .classify_hdi, hdi$CI_low, c(100, 100 * hdi$CI))
   out$HDI_high <- sapply(out$x, .classify_hdi, rev(hdi$CI_high), c(rev(100 * hdi$CI), 100))
-  out$fill <- as.factor(ifelse(out$HDI_low > out$HDI_high, out$HDI_low, out$HDI_high))
+  out$fill <- as.factor(pmax(out$HDI_low, out$HDI_high))
   out$height <- out$y
   out$y <- name
 
@@ -198,7 +198,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 #' library(rstanarm)
 #' library(bayestestR)
 #' set.seed(123)
-#' m <<- suppressWarnings(stan_glm(Sepal.Length ~ Petal.Width * Species, data = iris, refresh = 0))
+#' m <- suppressWarnings(stan_glm(Sepal.Length ~ Petal.Width * Species, data = iris, refresh = 0))
 #' result <- hdi(m)
 #' result
 #' plot(result)
