@@ -198,9 +198,30 @@ see_colors <- function(...) {
 see_palettes <- list(
   `full` = see_colors(),
   `ice` = see_colors("indigo", "blue", "blue grey", "cyan", "light blue"),
-  `rainbow` = see_colors("purple", "deep purple", "indigo", "blue", "light blue", "green", "light green", "lime", "amber", "orange", "red", "pink"),
+  `rainbow` = see_colors(
+    "purple",
+    "deep purple",
+    "indigo",
+    "blue",
+    "light blue",
+    "green",
+    "light green",
+    "lime",
+    "amber",
+    "orange",
+    "red",
+    "pink"
+  ),
   `contrast` = see_colors("blue", "orange", "yellow", "green", "red"),
-  `complement` = see_colors("blue", "blue grey", "green", "light green", "yellow", "amber", "red"),
+  `complement` = see_colors(
+    "blue",
+    "blue grey",
+    "green",
+    "light green",
+    "yellow",
+    "amber",
+    "red"
+  ),
   `light` = see_colors("light blue", "pink", "lime", "light green", "orange")
 )
 
@@ -230,7 +251,7 @@ palette_see <- function(palette = "contrast", reverse = FALSE, ...) {
       datawizard::text_concatenate(names(palette_list), last = " or ", enclose = "`"),
       "."
     ), "Using default palette now.")
-    warning(insight::format_message(msg), call. = FALSE)
+    insight::format_warning(msg)
     palette <- 1
   }
   pal <- palette_list[[palette]]
