@@ -1,7 +1,7 @@
 test_that("`plot.see_estimate_density()` works", {
-  skip_if_not_or_load_if_installed("correlation")
-  skip_if_not_or_load_if_installed("rstanarm")
-  skip_if_not_or_load_if_installed("ggridges")
+  skip_if_not_installed("correlation")
+  skip_if_not_installed("rstanarm")
+  skip_if_not_installed("ggridges")
 
   set.seed(123)
   result <- bayestestR::estimate_density(m_rstan)
